/******************************************************************************/
/*                                                                            */
/*             SAS Program to Score the TIMSS Numeracy 2015 Items             */
/*                           TIMSS 2015 User Guide                            */
/*                                                                            */
/******************************************************************************/

OPTIONS NONOTES MPRINT ;

%MACRO SCOREIT (ITEM, TYPE, RIGHT, NR, NA, OM, OTHER) ;

  * Code for multiple-choice items ;

  %IF %UPCASE(&TYPE) = "MC" %THEN %DO ;
    SCORE = 0 ;
      IF &ITEM = &RIGHT             THEN SCORE = 1 ; * Item Key ;
      IF &ITEM = &NR                THEN SCORE = 0 ; * Not Reached ;
      IF &ITEM = &NA                THEN SCORE = . ; * Not Administered ;
      IF &ITEM = &OM                THEN SCORE = 0 ; * Omitted ;
      IF &ITEM = &OTHER             THEN SCORE = 0 ; * Other Missing ;
    &ITEM = SCORE ;
  %END ;

  * Code for constructed-response items ;

  %IF %UPCASE(&TYPE) = "CR" %THEN %DO ;
    SCORE = 0 ;
      IF &ITEM >= 20 AND &ITEM < 30 THEN SCORE = 2 ; * Full Credit ;
      IF &ITEM >= 10 AND &ITEM < 20 THEN SCORE = 1 ; * Partial Credit ;
      IF &ITEM >= 70 AND &ITEM < 80 THEN SCORE = 0 ; * No Credit ;
      IF &ITEM = &NR                THEN SCORE = 0 ; * Not Reached ;
      IF &ITEM = &NA                THEN SCORE = . ; * Not Administered ;
      IF &ITEM = &OM                THEN SCORE = 0 ; * Omitted ;
      IF &ITEM = &OTHER             THEN SCORE = 0 ; * Other Missing ;
    &ITEM = SCORE ;
  %END ;

%MEND SCOREIT ;

%MACRO DOIT (INDIR   = ,
             COUNTRY = ) ;

  LIBNAME LIBDAT "&INDIR" ;

  * Start of country processing loop ;

  %LET I = 1 ;
  %DO %WHILE(%LENGTH(%SCAN(&COUNTRY,&I))) ;
    %LET CTRY = %SCAN(&COUNTRY,&I) ;

    * Get the student achievement data ;

    DATA LIBDAT.ASC&CTRY.N1;     * Output File ;
         SET LIBDAT.ASA&CTRY.N1; * Input File ;

         * Score multiple-choice items with A key ;

         ARRAY ARIGHT MN11259   MN11042D  MN11042E  MN11193   MN11002   MN11262   M061050
                      MN11231   MN11045   MN11240   MN11129   M061040   M061171   MN11039   ;
         DO OVER ARIGHT ; %SCOREIT (ARIGHT, "MC", 1, .R, .A, ., .I) ; END ;

         * Score multiple-choice items with B key ;

         ARRAY BRIGHT MN11255   MN11031   MN11042B  MN11042C  MN11134   MN11253   MN11182B
                      MN11034   MN11239   M061265B  MN11076   MN11067   MN11061   MN11023
                      MN11260   MN11170   MN11001   ;
         DO OVER BRIGHT ; %SCOREIT (BRIGHT, "MC", 2, .R, .A, ., .I) ; END ;

         * Score multiple-choice items with C key ;

         ARRAY CRIGHT MN11135   MN11009   MN11182A  MN11047A  M061029   M061206   M061185
                      MN11142   MN11005   MN11019   MN11211   MN11056   MN11041   M061026
                      MN11252   MN11214   ;
         DO OVER CRIGHT ; %SCOREIT (CRIGHT, "MC", 3, .R, .A, ., .I) ; END ;

         * Score multiple-choice items with D key ;

         ARRAY DRIGHT MN11221   MN11047B  M061031   MN11268   MN11265   MN11036   MN11305
                      M061273   M061222   MN11278A  MN11278B  MN11040   MN11032   ;
         DO OVER DRIGHT ; %SCOREIT (DRIGHT, "MC", 4, .R, .A, ., .I) ; END ;

         * Score Constructed-Response Items ;

         ARRAY CONSTR MN11114   MN11216   MN11027   MN11227   MN11267   MN11042   MN11184
                      MN11190   MN11024   MN11212   MN11146   MN11177   MN11158   MN11272
                      MN11017   MN11125   MN11077   MN11223   MN11175   MN11202   MN11299
                      M061272   M061243   M061167   M061265A  M061239   MN11141   MN11256A
                      MN11256B  MN11108   MN11062   MN11174   MN11043   MN11270   MN11145
                      MN11014   MN11300   MN11028   MN11154   MN11057   MN11113   MN11200
                      MN11218   MN11225   MN11179   MN11303   M061034   M061228   M061166
                      M061080   M061076   M061084   MN11128   MN11022   MN11010   MN11136
                      MN11261   MN11033   MN11195   MN11188   MN11055   MN11116A  MN11116B
                      MN11066A  MN11066B  MN11068   MN11269   MN11235   ;
         DO OVER CONSTR ; %SCOREIT (CONSTR, "CR",  , .R, .A, ., .I) ; END ;

    RUN ;

    * End of country processing loop ;

    %LET I = %EVAL(&I + 1) ;
  %END ;

%MEND DOIT ;

%DOIT (INDIR   = <Specify location of SAS data files using format "x:\xxx"> ,
       COUNTRY = BHR IDN IRN JOR KWT MAR ZAF
                 ABA ) ;
