********************************************************************************
*                                                                              *
*             SPSS Program to Score the TIMSS 2015 4th Grade Items             *
*                            TIMSS 2015 User Guide                             *
*                                                                              *
********************************************************************************.

SET MPRINT=ON .

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

  * Code for multiple-choice items .

  !IF (!UPCASE(!TYPE)=MC) !THEN
    !DO !I !IN (!ITEM) .
      RECODE !I (!RIGHT     = 1      ) /* Item Key         */
                (!NR        = 0      ) /* Not Reached      */
                (!NA        = SYSMIS ) /* Not Administered */
                (!OM        = 0      ) /* Omitted          */
                (!OTHER     = 0      ) /* Other Missing    */
                (ELSE       = 0      ) .
    !DOEND .
  !IFEND .

  * Code for constructed-response items .

  !IF (!UPCASE(!TYPE)=CR) !THEN
    !DO !I !IN (!ITEM) .
      RECODE !I (20 THRU 29 = 2      ) /* Full Credit      */
                (10 THRU 19 = 1      ) /* Partial Credit   */
                (70 THRU 79 = 0      ) /* No Credit        */
                (!NR        = 0      ) /* Not Reached      */
                (!NA        = SYSMIS ) /* Not Administered */
                (!OM        = 0      ) /* Omitted          */
                (!OTHER     = 0      ) /* Other Missing    */
                (ELSE       = 0      ) .
    !DOEND .
  !IFEND .

!ENDDEFINE .

DEFINE DOIT (INDIR  = !CHAREND('/') /
             OUTDIR = !CHAREND('/') /
             INFILE = !CHAREND('/') ) .

  * Get the student achievement data .

  GET FILE = !QUOTE(!CONCAT(!INDIR,'\',!INFILE,'.SAV')) .

  * Score multiple-choice items with A key .

  SCOREIT TYPE = MC / ITEM = M041034   M061050   M051407   M061172   M041125   M041135   M041264
                             M051140   M041046   M041169   M061040   M061171   M051224   M061018A
                             M061018B  M061018D  M061106   M051211   M051100   M061232   M051040
                             M051216A  M061240A  M061240B  M061077   S041010   S041017   S041124
                             S041303   S061105   S061028   S051004   S051026A  S051026D  S051121C
                             S051121E  S051105   S061022   S041008   S051188B  S051188C  S051188E
                             S051102   S041070   S061108   S061169   S051142   S061083D  S061142AB
                             S061142AC S051138B  S051191   S061132   S061042B  S061155   S051054
                             S061048   S061124B  S061124D  S061124E  S061116B  S061116D  /
          RIGHT = 1 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with B key .

  SCOREIT TYPE = MC / ITEM = M041004   M041132   M061265B  M051070   M051093   M061275   M041068
                             M041268   M051094   M051129   M041280   M041048   M041262   M051049
                             M051207   M061018C  M061274   M051226   M061108   M061211B  M051216B
                             M051221   M061240C  M061041   S061098   S051026B  S051026C  S051121A
                             S051121B  S051121D  S051111   S061140   S061118   S061097   S041191
                             S051087   S051188A  S051188D  S041052   S061141   S061080   S051035
                             S061083C  S061142AA S061115A  S051051   S051138A  S051065   S061042A
                             S051193   S051063   S061047   S061096   S061124C  S061116C  S061116E  /
          RIGHT = 2 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with C key .

  SCOREIT TYPE = MC / ITEM = M041302A  M041153   M061029   M061206   M061185   M051018   M051077
                             M061223   M041289   M041065A  M041151   M051017   M041333   M041177
                             M061026   M051052   M051427   M061179   M051075   M051103   M051102
                             M061246   M061049   M061244   S041119   S061065   S061049B  S051041
                             S051114   S061135   S041223   S051185   S041050   S041209   S041102
                             S051131A  S051157   S061016A  S061083B  S061115B  S051029   S051099
                             S061133A  S051012   S051180   S051148   S061046   /
          RIGHT = 3 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with D key .

  SCOREIT TYPE = MC / ITEM = M041023   M041254   M041191   M061031   M051410   M061151   M061269
                             M041096   M051060   M051125B  M041298   M041007   M041271   M061273
                             M061222   M051098   M051502   M061052   M061207   M051115   M061252
                             S041034   S041105   S061075   S061049A  S051110   S061134   S041009
                             S041026   S041134C  S051137   S061007   S061109   S051003   S051131B
                             S061071   S051161   S061120   S061133B  S051106   S061107   /
          RIGHT = 4 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score Constructed-Response Items .

  SCOREIT TYPE = CR / ITEM = M041087   M041124   M041302B  M041302C  M041165   M041174   M061272
                             M061243   M061167   M061265A  M061239   M051205   M051039   M051055
                             M051006   M051059   M051134   M061027   M061255   M061021   M061043
                             M061081A  M061081B  M041291   M041065B  M041257   M041182   M041200
                             M051111   M051089   M051227   M051061A  M051061B  M051061C  M051061Z
                             M051236   M051125A  M041059   M041267   M041276A  M041276B  M061034
                             M061228   M061166   M061080   M061076   M061084   M051206   M051045
                             M051030   M051533   M051080   M061018   M061248   M061039   M061079
                             M061236   M061266   M051401   M051402   M051131   M051217   M051079
                             M051009   M061178   M061271   M061256   M061182   M061095   M061264
                             M061211A  M051043   M051008   M051031A  M051031B  M051508   M051507A
                             M051507B  M061240   M061254   M061173   M061261   M061224   M061069A
                             M061069B  S041186   S041037   S041149A  S041149B  S041149Z  S041032
                             S041068   S061010   S061130   S061081   S061060   S061031   S061172
                             S051037   S051008   S051026Z  S051130   S051121Z  S051147   S061069
                             S061019   S061036   S061160   S061159   S061091   S041177   S041183
                             S041195   S041134A  S041134B  S041107   S041113   S051048   S051164
                             S051186   S051007   S051188Z  S051201   S051095   S041027   S041043
                             S041006   S041301   S041033   S041077   S041081   S061023   S061054
                             S061006   S061088   S061151   S061150   S051044   S051168   S051010
                             S051059   S051151   S061138   S061016B  S061011   S061083   S061034
                             S061044   S061142A  S061142B  S051138Z  S051194   S051077   S051200
                             S051075   S051175   S061025   S061074   S061093   S061161   S061041A
                             S061041B  S051024   S051132A  S051132B  S051040   S051115   S061014
                             S061056   S061015   S061113   S061124   S061116   /
          RIGHT = 0 / NR = 96 / NA = SYSMIS / OM = 99 / OTHER = 90 .

  EXECUTE .

  * Save the student data .

  SAVE OUTFILE = !QUOTE(!CONCAT(!OUTDIR,'\',!INFILE,'_SCR.SAV')) .

  NEW FILE .

!ENDDEFINE .

DOIT INDIR  = <Specify location of input SPSS data file using format "x:\xxx"> /
     OUTDIR = <Specify location of output SPSS data file using format "x:\xxx"> /
     INFILE = <Specify name of merged SPSS student achievement data file> .
