********************************************************************************
*                                                                              *
*             SPSS Program to Score the TIMSS Numeracy 2015 Items              *
*                            TIMSS 2015 User Guide                             *
*                                                                              *
********************************************************************************.

SET MPRINT=ON .

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

  * Code for multiple-choice items .

  !IF (!UPCASE(!TYPE)=MC) !THEN
    !DO !I !IN (!ITEM) .
      RECODE !I (!RIGHT     = 1      ) /* Item Key         */
                (!NR        = 0      ) /* Not Reached      */
                (!NA        = SYSMIS ) /* Not Administered */
                (!OM        = 0      ) /* Omitted          */
                (!OTHER     = 0      ) /* Other Missing    */
                (ELSE       = 0      ) .
    !DOEND .
  !IFEND .

  * Code for constructed-response items .

  !IF (!UPCASE(!TYPE)=CR) !THEN
    !DO !I !IN (!ITEM) .
      RECODE !I (20 THRU 29 = 2      ) /* Full Credit      */
                (10 THRU 19 = 1      ) /* Partial Credit   */
                (70 THRU 79 = 0      ) /* No Credit        */
                (!NR        = 0      ) /* Not Reached      */
                (!NA        = SYSMIS ) /* Not Administered */
                (!OM        = 0      ) /* Omitted          */
                (!OTHER     = 0      ) /* Other Missing    */
                (ELSE       = 0      ) .
    !DOEND .
  !IFEND .

!ENDDEFINE .

DEFINE DOIT (INDIR  = !CHAREND('/') /
             OUTDIR = !CHAREND('/') /
             INFILE = !CHAREND('/') ) .

  * Get the student achievement data .

  GET FILE = !QUOTE(!CONCAT(!INDIR,'\',!INFILE,'.SAV')) .

  * Score multiple-choice items with A key .

  SCOREIT TYPE = MC / ITEM = MN11259   MN11042D  MN11042E  MN11193   MN11002   MN11262   M061050
                             MN11231   MN11045   MN11240   MN11129   M061040   M061171   MN11039  /
          RIGHT = 1 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with B key .

  SCOREIT TYPE = MC / ITEM = MN11255   MN11031   MN11042B  MN11042C  MN11134   MN11253   MN11182B
                             MN11034   MN11239   M061265B  MN11076   MN11067   MN11061   MN11023
                             MN11260   MN11170   MN11001   /
          RIGHT = 2 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with C key .

  SCOREIT TYPE = MC / ITEM = MN11135   MN11009   MN11182A  MN11047A  M061029   M061206   M061185
                             MN11142   MN11005   MN11019   MN11211   MN11056   MN11041   M061026
                             MN11252   MN11214   /
          RIGHT = 3 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with D key .

  SCOREIT TYPE = MC / ITEM = MN11221   MN11047B  M061031   MN11268   MN11265   MN11036   MN11305
                             M061273   M061222   MN11278A  MN11278B  MN11040   MN11032   /
          RIGHT = 4 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score Constructed-Response Items .

  SCOREIT TYPE = CR / ITEM = MN11114   MN11216   MN11027   MN11227   MN11267   MN11042   MN11184
                             MN11190   MN11024   MN11212   MN11146   MN11177   MN11158   MN11272
                             MN11017   MN11125   MN11077   MN11223   MN11175   MN11202   MN11299
                             M061272   M061243   M061167   M061265A  M061239   MN11141   MN11256A
                             MN11256B  MN11108   MN11062   MN11174   MN11043   MN11270   MN11145
                             MN11014   MN11300   MN11028   MN11154   MN11057   MN11113   MN11200
                             MN11218   MN11225   MN11179   MN11303   M061034   M061228   M061166
                             M061080   M061076   M061084   MN11128   MN11022   MN11010   MN11136
                             MN11261   MN11033   MN11195   MN11188   MN11055   MN11116A  MN11116B
                             MN11066A  MN11066B  MN11068   MN11269   MN11235   /
          RIGHT = 0 / NR = 96 / NA = SYSMIS / OM = 99 / OTHER = 90 .

  EXECUTE .

  * Save the student data .

  SAVE OUTFILE = !QUOTE(!CONCAT(!OUTDIR,'\',!INFILE,'_SCR.SAV')) .

  NEW FILE .

!ENDDEFINE .

DOIT INDIR  = <Specify location of input SPSS data file using format "x:\xxx"> /
     OUTDIR = <Specify location of output SPSS data file using format "x:\xxx"> /
     INFILE = <Specify name of merged SPSS student achievement data file> .
