********************************************************************************
*                                                                              *
*             SPSS Program to Score the TIMSS 2015 8th Grade Items             *
*                            TIMSS 2015 User Guide                             *
*                                                                              *
********************************************************************************.

SET MPRINT=ON .

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

  * Code for multiple-choice items .

  !IF (!UPCASE(!TYPE)=MC) !THEN
    !DO !I !IN (!ITEM) .
      RECODE !I (!RIGHT     = 1      ) /* Item Key         */
                (!NR        = 0      ) /* Not Reached      */
                (!NA        = SYSMIS ) /* Not Administered */
                (!OM        = 0      ) /* Omitted          */
                (!OTHER     = 0      ) /* Other Missing    */
                (ELSE       = 0      ) .
    !DOEND .
  !IFEND .

  * Code for constructed-response items .

  !IF (!UPCASE(!TYPE)=CR) !THEN
    !DO !I !IN (!ITEM) .
      RECODE !I (20 THRU 29 = 2      ) /* Full Credit      */
                (10 THRU 19 = 1      ) /* Partial Credit   */
                (70 THRU 79 = 0      ) /* No Credit        */
                (!NR        = 0      ) /* Not Reached      */
                (!NA        = SYSMIS ) /* Not Administered */
                (!OM        = 0      ) /* Omitted          */
                (!OTHER     = 0      ) /* Other Missing    */
                (ELSE       = 0      ) .
    !DOEND .
  !IFEND .

!ENDDEFINE .

DEFINE DOIT (INDIR  = !CHAREND('/') /
             OUTDIR = !CHAREND('/') /
             INFILE = !CHAREND('/') ) .

  * Get the student achievement data .

  GET FILE = !QUOTE(!CONCAT(!INDIR,'\',!INFILE,'.SAV')) .

  * Score multiple-choice items with A key .

  SCOREIT TYPE = MC / ITEM = M042052   M062208A  M062208C  M062124   M052142   M062245   M042243
                             M042120   M052131   M052121A  M052044   M042132   M042252   M062164
                             M062084   M052413   M052407   M062219   M052068   M062095   M062076
                             M052092   M052418B  M062146   M062242   S042016   S042068   S062189A
                             S062189D  S062189E  S062010B  S062010D  S062268   S052280   S052043B
                             S052043C  S052289B  S062018B  S062018E  S062205   S062024A  S042126
                             S052246   S052192   S052096   S042042   S062055   S062225   S062262
                             S052076   S052113   S062173AA S062173AC S062173B  S052090A  S052262
                             S052015A  S052015B  S052015F  S052028   S062279   S062037   S062242A
                             S062242E  S052095D  S052206   S052294   S062097   S062047A  S062047C
                             S062235   S062180   S062022A  S062022B  S062022C  /
          RIGHT = 1 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with B key .

  SCOREIT TYPE = MC / ITEM = M042202   M042268   M062208B  M062208D  M062153   M062202   M052103
                             M052410   M052170   M062329   M062212   M062284   M042060   M042255
                             M052422A  M052505   M042158   M062351   M062174   M062132B  M052078
                             M052130   M062335   M062123B  M052079   M052147   M052067   M062230
                             M052024   M052072   M052161   M062001   S042249   S042164   S062189B
                             S062094   S062010A  S062010C  S052261   S052043A  S052043D  S052179
                             S062099   S062018A  S062018D  S042257   S052003   S052303A  S042003
                             S042222C  S042218   S042217   S062233   S052248   S052299   S062284
                             S062158   S062004   S062173AB S062173AD S052015C  S052015D  S052015E
                             S052217   S062247   S062186   S062242B  S062242D  S052012   S052095B
                             S052095C  S052134   S062091A  S062047B  S062022D  /
          RIGHT = 2 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with C key .

  SCOREIT TYPE = MC / ITEM = M042182   M042049   M042100   M042271   M062325   M052209   M052064
                             M052066   M062115   M042234   M042203   M052090   M042015   M042196
                             M042257   M042261   M062005   M062261   M052034   M052073   M062040
                             M062123A  M052204   M052419A  M052419B  M062194   M052063   M052083
                             M052082   M062067   M062120   S042258   S062103A  S062271   S052194
                             S052289A  S062132   S062153   S062018C  S042053   S042182   S042210
                             S052071   S052063   S042065   S042312   S062035   S062171   S052282
                             S052107   S062090   S062032   S052267   S052038   S062119   S052069
                             S052243C  S062091B  S062246   /
          RIGHT = 3 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with D key .

  SCOREIT TYPE = MC / ITEM = M042076   M042240   M062074   M062246   M062106   M052006   M052057
                             M062350   M042183   M052017   M052422B  M042112   M042109   M062223
                             M052134   M052426   M062149   M062133   M052208   M052115   M062271
                             M062171   M062320   M052125   M052046   M052418A  M062341   S042216
                             S062253   S062044   S062170   S052256   S052159   S062106   S062190
                             S042015   S042309   S052276   S052125   S052232   S042110   S042280
                             S062007   S062144   S052144   S062159   S062075   S052026   S052130
                             S062089   S062177   S052150   S052112A  /
          RIGHT = 4 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score Constructed-Response Items .

  SCOREIT TYPE = CR / ITEM = M042081   M042302A  M042302B  M042302C  M042093   M042159   M042164
                             M042167   M062208   M062111A  M062111B  M062237   M062314   M062183
                             M062286   M052035   M052016   M052126   M052041   M052417   M052501
                             M062151   M062346   M062056   M062317   M062078   M062287   M062345A
                             M042019   M042023   M042197   M042066   M042248   M042229A  M042229B
                             M042229Z  M042080A  M042080B  M042264   M042224   M052217   M052021
                             M052095   M052094   M052121B  M052042   M052047   M042194   M042114A
                             M042114B  M042050   M042074A  M042074B  M042074C  M042151   M062139
                             M062142   M062027   M062244   M062300   M062254   M062132A  M052174A
                             M052174B  M052110   M052105   M052036   M052502   M052117   M062150
                             M062002   M062241   M062105   M062288   M062173   M052364   M052215
                             M052087   M052048   M052039   M052421   M062152   M062215   M062143
                             M062030   M062301   M062344   M062296   M052058A  M052058B  M052229
                             M052146A  M052146B  M062214   M062154   M062250A  M062250B  M062170
                             M062192   M062072   S042005   S042300A  S042300B  S042300C  S042319
                             S042094   S042293A  S042293B  S042195   S042400   S062189   S062118
                             S062103B  S062010   S062051   S062046   S062149   S062234   S052092A
                             S052092B  S052092C  S052092D  S052092Z  S052263A  S052263B  S052265
                             S052043Z  S052233   S052289C  S062095   S062064   S062163   S062018
                             S062143   S062276   S062050   S062024B  S042408   S042049A  S042049B
                             S042402   S042228A  S042228B  S042228C  S042176   S042211   S042135
                             S052303B  S052145   S052049   S052141   S052116   S052110   S042030
                             S042222A  S042222B  S042088   S042104   S042064   S042273   S042301
                             S042406   S062275   S062111   S062116A  S062116B  S062116C  S062162
                             S052272   S052085A  S052085B  S052094   S052146   S052214   S052101
                             S062274   S062098A  S062098B  S062043   S062005   S062175   S062173A
                             S052090B  S052273   S052015Z  S052051   S052189   S052099   S052118
                             S062112   S062093   S062006   S062067   S062211A  S062211B  S062033
                             S062242   S052006   S052021   S052095Z  S052054   S052243A  S052243B
                             S052112B  S062100   S062101   S062128   S062047   S062042   S062250
                             S062056   S062022   S062243   /
          RIGHT =  0 / NR = 96 / NA = SYSMIS / OM = 99 / OTHER = 90 .

  EXECUTE .

  * Save the student data .

  SAVE OUTFILE = !QUOTE(!CONCAT(!OUTDIR,'\',!INFILE,'_SCR.SAV')) .

  NEW FILE .

!ENDDEFINE .

DOIT INDIR  = <Specify location of input SPSS data file using format "x:\xxx"> /
     OUTDIR = <Specify location of output SPSS data file using format "x:\xxx"> /
     INFILE = <Specify name of merged SPSS student achievement data file> .
